<?php
/*
Plugin Name: Covert Messenger PRO
Description: Simple plugin that generates instant messenger styled ads on your blog, grabbing your readers attention and "forcing" them to click your links. This is the Pro version with loads of extra features.
Version: 2.3
Author: IM Wealth Builders Ltd
Author URI: http://imwealthbuilders.com/newplugins
Requires at least: 6.0
Tested up to: 6.0.1

Copyright 2022 IM Wealth Builders

*/

define('IMWB_CIM_PRO_VERSION', '2.3');
define('IMWB_CIM_PRO_FOLDER', 'covertmessenger-pro');
define('IMWB_CIM_PRO_PREFIX', 'imwb_');

require_once(WP_PLUGIN_DIR.'/'.IMWB_CIM_PRO_FOLDER."/mobile-detect.php");

/**
 * This is where you add comments for your plugin class
 * @author John Merrick
 */
class IMWB_Covert_Messenger_PRO {

	 var $plugin_name = "";
	 var $plugin_url = "";
	 var $variationCount = 3;
	 var $messengerCount = 5;
    var $templates = Array("Aim" => array("Small" => "AS.png", "Medium" => "AM.png"),
                           "Facebook" => array("Small" => "FS.png", "Medium" => "FM.png", "Large" => "FL.gif"),
                           "ICQ" => Array("Small" => "IS.png", "Medium" => "IM.png"),
                           "MSN" => Array("Small" => "MS.png", "Medium" => "MM.png"),
                           "Yahoo" => Array("Small" => "YS.png", "Medium" => "YM.png"),
                           "Chat Bar" => Array("Red" => "G1.gif","Blue" => "G2.gif","Grey" => "G3.gif"),
                           "Chat Box I" => Array("Red" => "G4.gif","Blue" => "G5.gif","Grey" => "G6.gif"),
                           "Chat Box II" => Array("Red" => "G7.gif","Blue" => "G8.gif","Grey" => "G9.gif"),
                           "Skype" => Array("Small" => "SS.png", "Medium" => "SM.png", "Large" => "SL.gif"),
                           "WhatsApp" => Array("Small" => "WS.png", "Medium" => "WM.png", "Large" => "WL.gif")
                       	);
    var $update;
    var $currentCIMNum = 0;
    var $mobble_detect;

	/**
	 * The constructor is executed when the class is instatiated and the plugin gets loaded.
	 * @return void
	 */
	function __construct() {

      $this->plugin_name = IMWB_CIM_PRO_PREFIX.IMWB_CIM_PRO_FOLDER;

   	// Hack to avoid firing on Admin Login or Registration page
   	if ( in_array( $GLOBALS['pagenow'], array( 'wp-login.php', 'wp-register.php' ) ) )
   	   return;

      $this->plugin_url = plugins_url(basename( dirname( __FILE__)));

   	if(is_admin()){
      	$this->setup_update_info();
      	add_action('wp_ajax_'.$this->plugin_name.'_clear_cookie', array(&$this, 'clear_cookie'));
   	   add_action('admin_init', array(&$this,'init_admin'));
   		add_action('admin_menu', array(&$this,'init_admin_menu'));
      	add_action('wp_ajax_'.$this->plugin_name.'_clear_cookie', array(&$this, 'clear_cookie'));
      	add_action('wp_ajax_'.$this->plugin_name.'_ctr_action', array(&$this,'ctr_action_callback'));
      	add_action('wp_ajax_nopriv_'.$this->plugin_name.'_ctr_action', array(&$this,'ctr_action_callback'));
   	}
   	else {
  			add_action('wp_enqueue_scripts', array(&$this, 'init_styles'), 20);
   		  add_action('wp_enqueue_scripts', array(&$this, 'init_scripts'),20);
     		add_action('wp_head', array(&$this, 'load_script'));
   	}
	}

	/**
	 *
	 * Returns an array of admin options
	 * @return Array
	 */
	function get_admin_options($msnNum) {
		$adminOptions = array('active' => "N",
		                      'im_show_delay' => '0',
		                      'im_hide_delay' => '0',
		                      'im_reshow_delay' => '0',
		                      'im_reshow_days' => '0',
		                      'show_samewindow' => "true",
		                      'where_shown' => serialize(Array('everywhere' => 'E')),
		                      'im_var_next' => 1,
		                      'play_sound' => 0,
		                      'track_users' => 'Y',
		                      'show_tablet' => 'Y',
		                      'show_mobile' => 'Y');

		$devOptions = get_option($this->plugin_name."-".$msnNum."-AdminOptions");
		if (!empty($devOptions)) {
			foreach ($devOptions as $key => $option)
				$adminOptions[$key] = $option;
		}
		update_option($this->plugin_name."-".$msnNum."-AdminOptions", $adminOptions);

		$adminOptions['where_shown'] = unserialize($adminOptions['where_shown']);

		// Get the message variations
		for($i = 1; $i <= $this->variationCount; $i++) {
		   $msgVariation = array( 'im_template' => $i == 1 ? 'AS.png' : 'N',
                     		     'im_url' => 'http://yourdomain.com',
		                          'im_from_name' => 'From: Joe Blogs',
                       		     'im_msg_text' => '<p>This is the message text for variation '.$i.'</p>',
                       		     'im_imp' => 0,
                       		     'im_ctr' => 0);

         $devOptions = get_option($this->plugin_name."-".$msnNum."-AdminOptions-Var$i");
         if (!empty($devOptions)) {
         	foreach ($devOptions as $key => $option)
         		$msgVariation[$key] = stripslashes($option);
         }

         update_option($this->plugin_name."-".$msnNum."-AdminOptions-Var$i", $msgVariation);

         $adminOptions['im_var'.$i] = $msgVariation;
		}

		return $adminOptions;
	}

	/**
	 *
	 * Save the passed array of admin options
	 * @return void
	 */
	function save_admin_options($options, $msnNum) {

			// Save the message variations
			for($i = 1; $i <= $this->variationCount; $i++) {
   			$msgVariation = $options['im_var'.$i];

   			update_option($this->plugin_name."-".$msnNum."-AdminOptions-Var$i", $msgVariation);

   			unset($options['im_var'.$i]);

   		}

   		$options['where_shown'] = serialize($options['where_shown']);

   		// Save the remaining options
   		update_option($this->plugin_name."-".$msnNum."-AdminOptions", $options);

   		return $this->get_admin_options($msnNum);
	}

	/**
	 * Register the admin option page stylesheet and scripts
	 */
	function init_admin() {

	   wp_register_style($this->plugin_name . '-page-stylesheet', $this->plugin_url.'/styles/admin_options_page.css');
      wp_register_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/style.css');
	   wp_register_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/admin_options_page.js');
  	   wp_register_script($this->plugin_name . '-reports-script', $this->plugin_url.'/scripts/admin_reports_page.js');
	}

	/**
	 * Loading the front end javascripts
	 * /scripts/script.js from the plugin directory.
	 * @return void
	 */
	function init_scripts() {

      wp_enqueue_script('jquery');
      wp_enqueue_script($this->plugin_name . '-script', $this->plugin_url.'/scripts/script.js', array('jquery'), '1.0');

	}

	/**
	 * Loads the stylesheet for this plugin.
	 * @return void
	 */
	function init_styles() {

		wp_enqueue_style($this->plugin_name . '-stylesheet', $this->plugin_url.'/styles/style.css', array(), '1.0', 'all');

	}


	/*
	 * Will only be called on our plugin admin page, enqueue our stylesheet here
	 */
	function load_admin_styles() {
	   wp_enqueue_style($this->plugin_name . '-page-stylesheet');
	   wp_enqueue_style($this->plugin_name . '-stylesheet');
      wp_enqueue_style('jquery-style', 'http://code.jquery.com/ui/1.10.3/themes/redmond/jquery-ui.css');
	}

	/**
	 * Loading the Admin side scripts
	 * @return void
	 */
	function load_admin_scripts() {

		wp_enqueue_script('jquery');
      wp_enqueue_script('jquery-ui-dialog');
	   wp_enqueue_script($this->plugin_name . '-videopopup-script', $this->plugin_url.'/scripts/jquery.videopopup.min.js', 'jquery' );
	   wp_enqueue_script($this->plugin_name . '-script','','jquery');
		wp_localize_script($this->plugin_name . '-script', 'IMWB_CIM_Ajax', array( 'ajaxurl' => admin_url( 'admin-ajax.php' ), 'nonce' => wp_create_nonce( 'imwb_cim_clear_cookie_nonce' ), 'plugin_url' => $this->plugin_url, 'curVarNum' => 1, 'varCount' => $this->variationCount) );

      add_filter('tiny_mce_before_init', array(&$this,'tinymce_settings'));
	}

   /**
    * Loading the Admin reports side scripts
    * @return void
    */
   function load_admin_reports_scripts() {

   	wp_enqueue_script('jquery');
      wp_enqueue_script('jquery-ui-dialog');
	   wp_enqueue_script($this->plugin_name . '-videopopup-script', $this->plugin_url.'/scripts/jquery.videopopup.min.js', 'jquery' );
      wp_enqueue_script($this->plugin_name . '-reports-script','',array('jquery'));

   }

	/**
	 * Adds a new admin menu and let's anyone that can manage options
	 * be able to use it.
	 * @return void
	 */
	function init_admin_menu() {
		// Add the menu page
		$hook_name = add_menu_page( 'Covert Messenger PRO Admin Menu',
		    'Covert Messenger PRO',
		    'manage_options',
		    $this->plugin_name . '-admin-menu',
		    array(&$this, 'main_menu_page'),
		    'dashicons-testimonial');

      $this->views[$hook_name] = '1';

      add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

		$hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Settings', 'Messenger 1', 'manage_options', $this->plugin_name . '-admin-menu', array(&$this, 'main_menu_page'));
		$this->views[$hook_name] = '1';
   	add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
   	add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

      $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Settings', 'Messenger 2', 'manage_options', $this->plugin_name . '-admin-menu-2', array(&$this, 'main_menu_page'));
      $this->views[$hook_name] = '2';
      add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

      $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Settings', 'Messenger 3', 'manage_options', $this->plugin_name . '-admin-menu-3', array(&$this, 'main_menu_page'));
      $this->views[$hook_name] = '3';
      add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

      $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Settings', 'Messenger 4', 'manage_options', $this->plugin_name . '-admin-menu-4', array(&$this, 'main_menu_page'));
      $this->views[$hook_name] = '4';
      add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

      $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Settings', 'Messenger 5', 'manage_options', $this->plugin_name . '-admin-menu-5', array(&$this, 'main_menu_page'));
      $this->views[$hook_name] = '5';
      add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
      add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_scripts'));

      $hook_name = add_submenu_page($this->plugin_name . '-admin-menu', 'Covert IM Reports', 'Reports', 'manage_options', $this->plugin_name . '-admin-menu-reports', array(&$this, 'reports_menu_page'));

	   add_action( 'admin_print_styles-' . $hook_name, array(&$this, 'load_admin_styles'));
	   add_action( 'admin_print_scripts-' . $hook_name, array(&$this, 'load_admin_reports_scripts'));
	}

	/**
	 * This function will be executed when the admin settings page is to be loaded
	 * @return void
	 */
	function main_menu_page() {

   	$this->currentCIMNum = $this->views[current_filter()];

		$devOptions = $this->get_admin_options($this->currentCIMNum);
		// Include the HTML from a separate file to keep the plugin class clean
		require "pages/admin_options_page.php";
	}

   /**
    * This function will be executed when the reports page is to be loaded
    * @return void
    */
   function reports_menu_page() {

   	// Include the HTML from a separate file to keep the plugin class clean
   	require "pages/admin_reports_page.php";
   }

   /**
    * Function is_tablet
    * For detecting tablet devices (needs work)
    */
   function is_tablet() {
   	return apply_filters( 'is_tablet', $this->mobble_detect->isTablet(), $this->mobble_detect );
   }

   /**
    * Function is_mobile
    * For detecting ANY mobile phone device
    */
   function is_mobile() {

   	$result = null;
   	if ( $this->is_tablet() ) {
   		$result = false;
   	} else {
   		$result = $this->mobble_detect->isMobile();
   	}
   	return apply_filters( 'is_mobile', $result, $this->mobble_detect );
   }

	/**
	 * Loads the front end scripts that runs the plugins
	 * @return void
	 */
	function load_script() {

      $canShow = false;

      $this->mobble_detect = new IMWB_Mobile_Detect();
      $this->mobble_detect->setDetectionType( 'extended' );

      for($i = 1; $i <= $this->messengerCount; $i++) {

         $devOptions = $this->get_admin_options($i);
		   if($devOptions['active'] == "N")
			   continue;

			if($devOptions['show_tablet'] == 'N' && $this->is_tablet()) continue;
			if($devOptions['show_mobile'] == 'N' && $this->is_mobile()) continue;

	      // See if this Messenger can be shwon
	      if($canShow = $this->can_show($devOptions['where_shown']))
	         break;
	   }

	   if(!$canShow)
	      return true;

	   $msnNum = $i;

      if((isset($_COOKIE['imwb_cim'.$msnNum.'_show']) && $_COOKIE['imwb_cim'.$msnNum.'_show'] == 'N') || (isset($_COOKIE['imwb_cim'.$msnNum.'_reshow']) && $_COOKIE['imwb_cim'.$msnNum.'_reshow'] == 'N'))
	      return true;

	   if(!is_admin()) {

     	   // Get the variation to show
     	   $varNum = $this->get_variation_to_show($devOptions, $msnNum);
   	   $varID = 'im_var'.$varNum;
?>
	<script type="text/javascript">
      jQuery(document).ready(function($) {

        var showTimer;
        var hideTimer;

        if(cimCookie('imwb_cim<?php echo $msnNum;?>_show') == 'N')
           return;

         // $() will work as an alias for jQuery() inside of this function
        $("body").append('<div id="imwb_cabim_panel" class="imwb_cabim_style_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions[$varID]['im_template']);?>"><img src="<?php echo $this->plugin_url."/tpl/".$devOptions[$varID]['im_template'];?>"><div id="imwb_cabim_dialog_from"><?php echo $this->sanitize_text($devOptions[$varID]['im_from_name']) ?></div><div id="imwb_cabim_dialog_text"><?php echo $this->sanitize_text($devOptions[$varID]['im_msg_text']) ?></div><img id="imwb_cabim_panel_close_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions[$varID]['im_template']);?>" src="<?php echo $this->plugin_url."/images/blank.png";?>"></div>   ');

        showTimer = setTimeout(imwb_show_cim, <?php echo $devOptions["im_show_delay"]*1000;?>);

        <?php if ($devOptions['play_sound'] == 1) {?>
        setTimeout(imwbcim_play_sound, <?php echo $devOptions["im_show_delay"]*1000;?>);
        function imwbcim_play_sound() {

           $("body").append('<object width="0" height="0" id="imwb_fjplayer" classid="clsid:D27CDB6E-AE6D-11cf-96B8-444553540000" style="position: absolute;top:0px;left:0px;max-width:0px"><param name="movie" value="<?php echo $this->plugin_url;?>/JFPlayIt.swf?url=<?php echo $this->plugin_url; ?>/alert.mp3"><embed src="<?php echo $this->plugin_url;?>/JFPlayIt.swf?url=<?php echo $this->plugin_url;?>/alert.mp3" name="player" width="0" height="0" type="application/x-shockwave-flash"></embed></object>');

           setTimeout(imwbcim_stop_sound, 3500);
        }

        function imwbcim_stop_sound() {
           $('#imwb_fjplayer').remove();
        }

        <?php } ?>
        function imwb_show_cim() {

           $("#imwb_cabim_panel").slideDown('slow');


           <?php if($devOptions['im_hide_delay'] > 0) {  ?>
              hideTimer = setTimeout(imwb_hide_cim, <?php echo ($devOptions["im_hide_delay"]*1000);?>);
           <?php } ?>
        }

        function imwb_hide_cim() {

           $("#imwb_cabim_panel").slideUp('slow');

           <?php if($devOptions['im_reshow_delay'] > 0) {  ?>
              showTimer = setTimeout(imwb_show_cim, <?php echo ($devOptions["im_reshow_delay"]*1000);?>);
           <?php } ?>
        }

        $("#imwb_cabim_panel_close_<?php echo preg_replace('/\.[^.]*$/', '', $devOptions[$varID]['im_template']);?>").click(function(event) {
             $("#imwb_cabim_panel").hide();

             clearTimeout(showTimer);
             clearTimeout(hideTimer);

             event.stopPropagation();

             cimCookie('imwb_cim<?php echo $msnNum;?>_show', 'N', <?php echo ($devOptions["im_reshow_days"]*24);?>,'<?php echo COOKIEPATH;?>');

        });

        $("#imwb_cabim_panel").click(function() {

        <?php if($devOptions['track_users'] == 'Y' || ($devOptions['track_users'] == 'N' && !is_admin() && !is_user_logged_in())) { ?>
           var data = {
               action :'<?php echo $this->plugin_name;?>_ctr_action',
               varDetails: '<?php echo $varNum;?>',
               msnNum: '<?php echo $msnNum;?>',
               nonce : '<?php echo wp_create_nonce( 'imwb_cim_ctr_action_nonce' );?>'
           };

           $.ajax({
             async: false,
             type: 'POST',
             url: '<?php echo admin_url( 'admin-ajax.php' );?>',
             data: data
           });

        <?php } ?>

           $("#imwb_cabim_panel").hide();
           cimCookie('imwb_cim<?php echo $msnNum;?>_show', 'N', <?php echo ($devOptions["im_reshow_days"]*24);?>,'<?php echo COOKIEPATH;?>');

           <?php
              if(!empty($devOptions[$varID]["im_url"])) {
                 if ($devOptions['show_samewindow'] == "true") { ?>
                 window.location = '<?php echo $devOptions[$varID]["im_url"];?>';
              <?php } else { ?>
                 window.open("<?php echo $devOptions[$varID]["im_url"];?>","_blank");
           <?php }
              }
           ?>

           return true;
        });

      });

	</script>
<?php
      }
	}

	/**
	 * Checks if Covert IM can be shown according to the passed in settings
	 * @return true/false
	 */
	function can_show($cimSettings) {
	   global $wp_query;

	   $cimPageIds = explode(',', $cimSettings['postid']);

	   // Set to everywhere
	   if(isset($cimSettings['everywhere']) && $cimSettings['everywhere'] == 'E')
	      return true;

      // If we are on the front page
      if(is_front_page() && isset($cimSettings['front']) && $cimSettings['front'] == 'F')
         return true;

      // If we are on the search results page
      if(is_search() && isset($cimSettings['search']) && $cimSettings['search'] == 'S')
         return true;

      // If we are on a page then see if set to display
      if(is_page() && isset($cimSettings['pageid']) && is_array($cimSettings['pageid']) && in_array($wp_query->post->ID,$cimSettings['pageid']))
         return true;

      // If we are on a page then check if we are set to display for this specific post
      if(is_single() && in_array($wp_query->post->ID,$cimPageIds))
         return true;

      // Were on a page so see if set to display for this category
      if(is_single() && ($cimSettings['catpage'] == 0 || $cimSettings['catpage'] == 2))
      {
         $postCats = get_the_category();
         foreach($postCats as $cat) {
            if(isset($cimSettings['catid']) && is_array($cimSettings['catid']) && in_array($cat->cat_ID,$cimSettings['catid']))
            return true;
         }
      }

      // If we are on a category archive page check if we are set to show
      if(is_category() && ($cimSettings['catpage'] == 0 || $cimSettings['catpage'] == 1)) {

         if(isset($cimSettings['catid']) && is_array($cimSettings['catid'])) {

            foreach($cimSettings['catid'] as $cat) {
               if(is_category($cat))
                  return true;
            }
         }
      }

      // Get here then no set to display
      return false;
	}

	function get_variation_to_show($cimSettings, $msnNum) {

	   // Get the next text to display
	   $varNext = $cimSettings['im_var_next'];

	   if($varNext > $this->variationCount)
	      $varNext = 1;

	   // Increment for the next bar text
	   $cimSettings['im_var_next'] = $varNext+1;

	   // make sure variation is active
	   if($cimSettings['im_var'. $varNext]['im_template'] == 'N')
	    return $this->get_variation_to_show($cimSettings, $msnNum);

     	// Update the Impressions
     	if($cimSettings['track_users'] == 'Y' || ($cimSettings['track_users'] == 'N' && !is_admin() && !is_user_logged_in()))
        	$cimSettings['im_var'. $varNext]['im_imp'] = $cimSettings['im_var'. $varNext]['im_imp']+1;

	   $this->save_admin_options($cimSettings, $msnNum);

   	return $varNext;
	}

	function sanitize_text($text) {

	   $text = do_shortcode($text);
      $text = preg_replace("/(\r\n|\r|\n)/", "", $text);
      $text = addslashes_gpc(stripslashes($text));

	   return $text;
	}

	function tinymce_settings($a) {
		$a["theme"] = "modern";
		$a["skin"] = "lightgray";
		$a["height"] = "160";
      $a["mode"] = "exact";
      $a["elements"] = "content";
		$a["element_format"] = "html";
		$a["theme_advanced_buttons1"] = "bold,italic,underline,separator,strikethrough,justifyleft,justifycenter,justifyright,separator,fontselect,fontsizeselect,forecolor,backcolor,separator,undo,redo";
		$a["theme_advanced_buttons2"] = "";
		$a["theme_advanced_path"] = false;
   	$a["setup"] = "function(ed) { ed.onExecCommand.add(function(ed, cmd, ui, val) { imwb_cim_editorChange(ed); }); ed.onChange.add(function(ed) { imwb_cim_editorChange(ed); });}";
      $a['handle_event_callback'] = 'imwb_cim_editorHandleEvent';
    	$a["content_css"] = plugins_url(basename( dirname( __FILE__)))."/styles/mce_custom.css";
		return $a;
	}

   function setup_update_info() {
      // Include Update Class
      require_once('imwb-plugin-update-checker-no-lic.php');
      $gdd21ed = __FILE__;

      $this->update=new ImwbPluginUpdateChecker_nolic($gdd21ed,IMWB_CIM_PRO_FOLDER,'plugin-update',true);
   }

	// AJAX Functions
	function clear_cookie() {

   	$nonce = $_POST['nonce'];
   	$msnNum = $_POST['msnNum'];

      if ( ! wp_verify_nonce( $nonce, 'imwb_cim_clear_cookie_nonce' ) )
         die ( 'Busted!');

		setcookie('imwb_cim'.$msnNum.'_show','Y',time()-8640000,COOKIEPATH);
		echo 'OK';

		die();
	}

	function ctr_action_callback() {
	   global $wpdb;

	   $nonce = $_POST['nonce'];

	   // check to see if the submitted nonce matches with the
	   // generated nonce we created earlier
	   if ( ! wp_verify_nonce( $nonce, 'imwb_cim_ctr_action_nonce' ) )
	       die ( 'Busted!');

	   // get the submitted parameters
	   $varDetails = $_POST['varDetails'];
	   $msnNum = $_POST['msnNum'];

	   // Get the variation detailsand update the CTR value
	   $varOptions = get_option($this->plugin_name."-".$msnNum."-AdminOptions-Var$varDetails");
      $varOptions['im_ctr'] = $varOptions['im_ctr']+1;
      update_option($this->plugin_name."-".$msnNum."-AdminOptions-Var$varDetails", $varOptions);

	   // response output
	   echo "OK";

	   // IMPORTANT: don't forget to "exit"
	   die();
	}
}

/**
 * Register the plugin
 */
$IMWBCovertMessengerPRO = null;

function run_covert_messenger_pro() {
  global $IMWBCovertMessengerPRO;
	$IMWBCovertMessengerPRO = new IMWB_Covert_Messenger_PRO();
}
run_covert_messenger_pro();

function imwb_cimp_admin_notice(){

   $plugin_file = 'covertmessenger/covertmessenger-plugin.php';

   if (is_plugin_active($plugin_file)) {
         echo "<div id='update-nag' class='update-nag'><strong>Covert Messenger PRO</strong> You must deactivate the standard version of Covert Messenger</div>";
   }
}

add_action('admin_notices', 'imwb_cimp_admin_notice');
